Method: Mixlib::Versioning::Format#parse

Defined in:
lib/mixlib/versioning/format.rb

#parse(_version_string) ⇒ Object

Parses the version string splitting it into it’s component version identifiers for easy comparison and sorting of versions. This method MUST be overriden by all descendants of this class.

Parameters:

  • version_string (String)

    string representation of the version

Raises:



94
95
96
# File 'lib/mixlib/versioning/format.rb', line 94

def parse(_version_string)
  raise Error, "You must override the #parse"
end